Module actions

Module actions 

Storage actions.

Traits

Memset
Extension trait for storage types that support memory setting operations
Slice
Extension trait for storage types that support slicing operations
SliceMut
Extension trait for storage types that support mutable slicing operations.