Module arena

Module arena 

Arena Allocator

This module provides an arena allocator for generally heap-like allocations. An ArenaAllocator can be created by taking ownership of a MemoryDescriptor instance.

The ArenaAllocator allocates memory contiguous regions using the offset_allocator crate, which builds on Sebastian Aaltonen’s ArenaAllocator

Structs

ArenaAllocator
Arena allocator backed by an instance of a MemoryDescriptor object.
ArenaBuffer
A buffer allocated from an ArenaAllocator.

Enums

ArenaError
Errors specific to arena allocation.