ArenaBuffer

Struct ArenaBuffer 

pub struct ArenaBuffer<S: MemoryDescription> { /* private fields */ }
A buffer allocated from an ArenaAllocator.

This struct wraps an Allocation from the offset_allocator crate, and provides methods for interacting with the allocated memory.

The buffer is backed by a MemoryDescription object, and the allocation is freed when the buffer is dropped.

Implementations

Source

impl<S> ArenaBuffer<S>

pub fn nixl_descriptor(&self) -> Option<NixlDescriptor>

Create a NIXL descriptor for this buffer with the correct offset and size.

This can be used when the base storage implements NixlCompatible to create a descriptor that points to just this buffer’s region.

Source

impl<S> ArenaBuffer<S>

pub fn agent_name(&self) -> &str

Get the agent name from registered storage.

This is a convenience method when using ArenaAllocator with NixlRegistered storage.

pub fn registered_descriptor(&self) -> NixlDescriptor

Get a NIXL descriptor that includes registration information.