Module nixl

Module nixl 

NIXL registration wrapper for storage types.

Structs

Agent
A NIXL agent that can create backends and manage memory
NixlAgent
A NIXL agent wrapper that tracks which backends were successfully initialized.
NixlBackendConfig
Configuration for NIXL backends.
NixlDescriptor
NIXL descriptor containing registration information.
NixlRegistered
Wrapper for storage that has been registered with NIXL.
NotificationMap
A safe wrapper around NIXL notification map
OptArgs
A safe wrapper around NIXL optional arguments
RegistrationHandle
XferDescList
A safe wrapper around a NIXL transfer descriptor list
XferRequest
A handle to a transfer request

Enums

MemType
Memory types supported by NIXL
XferOp

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
NixlCompatible
Trait for storage types that can be registered with NIXL.
NixlMemory
Combined trait for memory that can be registered with NIXL.
NixlRegisterExt
Extension trait providing ergonomic .register() method for NIXL registration.
RegisteredView
View trait for accessing registration information without unwrapping.
Serialize
A data structure that can be serialized into any data format supported by Serde.

Functions

is_stub
register_with_nixl
Register storage with a NIXL agent.

Derive Macros

Deserialize
Serialize