NixlRegistered

Struct NixlRegistered 

pub struct NixlRegistered<S: NixlCompatible> { /* private fields */ }
Wrapper for storage that has been registered with NIXL.

This wrapper ensures proper drop order: the registration handle is dropped before the storage, ensuring deregistration happens before the memory is freed.

Implementations

Source

impl<S: MemoryDescriptor + NixlCompatible> NixlRegistered<S>

pub fn storage(&self) -> &S

Get a reference to the underlying storage.

pub fn storage_mut(&mut self) -> &mut S

Get a mutable reference to the underlying storage.

pub fn is_registered(&self) -> bool

Check if the registration handle is still valid.

pub fn into_storage(self) -> S

Consume this wrapper and return the underlying storage.

This will deregister the storage from NIXL.