NixlMemory

Trait NixlMemory 

pub trait NixlMemory: MemoryDescriptor + NixlCompatible { }
Combined trait for memory that can be registered with NIXL.

This supertrait enables type erasure via Arc<dyn NixlMemory>. Any type implementing both MemoryDescriptor and NixlCompatible automatically implements this trait via the blanket implementation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors