NixlRegisterExt

Trait NixlRegisterExt 

pub trait NixlRegisterExt:
    MemoryDescriptor
    + NixlCompatible
    + Sized {
    // Provided method
    fn register(
        self,
        agent: &NixlAgent,
        opt: Option<&OptArgs>,
    ) -> Result<NixlRegistered<Self>, Self> { ... }
}
Extension trait providing ergonomic .register() method for NIXL registration.

This trait is automatically implemented for all types that implement both MemoryDescriptor and NixlCompatible. Import this trait to use the method syntax:

Provided Methods

fn register( self, agent: &NixlAgent, opt: Option<&OptArgs>, ) -> Result<NixlRegistered<Self>, Self>

Get this memory as NIXL-registered.

This operation is idempotent - it’s a no-op if the memory is already registered.

Arguments
  • agent - The NIXL agent to register with
  • opt - Optional arguments for registration
Returns

A NixlRegistered wrapper on success, or the original storage on failure.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors