pub fn get_current_cpu_numa_node() -> NumaNodeExpand description
Get the current CPU’s NUMA node.
Uses the Linux getcpu syscall to determine which NUMA node the current CPU belongs to.
Returns NumaNode::UNKNOWN if the syscall fails.
pub fn get_current_cpu_numa_node() -> NumaNodeGet the current CPU’s NUMA node.
Uses the Linux getcpu syscall to determine which NUMA node the current CPU belongs to.
Returns NumaNode::UNKNOWN if the syscall fails.