DiskStorage

Struct DiskStorage 

pub struct DiskStorage { /* private fields */ }
Disk-backed storage using memory-mapped files with O_DIRECT support.

Implementations

Source

impl DiskStorage

pub fn new(size: usize) -> Result<Self>

Creates a new disk storage of the given size in the default cache directory.

pub fn new_at(path: impl AsRef<Path>, len: usize) -> Result<Self>

Creates a new disk storage at the specified path with the given size.

pub fn fd(&self) -> u64

Returns the file descriptor of the backing file.

pub fn path(&self) -> &Path

Returns the path to the backing file.

Unlinks the backing file from the filesystem. This means that when this process terminates, the file will be automatically deleted by the OS. Unfortunately, GDS requires that files we try to register must be linked. To get around this, we unlink the file only after we’ve registered it with NIXL.

pub fn unlinked(&self) -> bool

Returns whether the backing file has been unlinked from the filesystem.