SystemStorage

Struct SystemStorage 

pub struct SystemStorage { /* private fields */ }
System memory allocated via malloc.

Implementations

Source

impl SystemStorage

pub fn new(len: usize) -> Result<Self>

Allocate new system memory of the given size.

pub unsafe fn as_ptr(&self) -> *const u8

Get a pointer to the underlying memory.

Safety

The caller must ensure the pointer is not used after this storage is dropped.

pub unsafe fn as_mut_ptr(&mut self) -> *mut u8

Get a mutable pointer to the underlying memory.

Safety

The caller must ensure the pointer is not used after this storage is dropped and that there are no other references to this memory.