Arena Allocator
This module provides an arena allocator for generally heap-like allocations.
An ArenaAllocator can be created by taking ownership of a MemoryDescriptor instance.
The ArenaAllocator allocates memory contiguous regions using the offset_allocator crate,
which builds on Sebastian Aaltonen’s ArenaAllocator
Structs
- Arena
Allocator - Arena allocator backed by an instance of a
MemoryDescriptorobject. - Arena
Buffer - A buffer allocated from an
ArenaAllocator.
Enums
- Arena
Error - Errors specific to arena allocation.