NIXL registration wrapper for storage types.
Structs
- Agent
- A NIXL agent that can create backends and manage memory
- Nixl
Agent - A NIXL agent wrapper that tracks which backends were successfully initialized.
- Nixl
Backend Config - Configuration for NIXL backends.
- Nixl
Descriptor - NIXL descriptor containing registration information.
- Nixl
Registered - Wrapper for storage that has been registered with NIXL.
- Notification
Map - A safe wrapper around NIXL notification map
- OptArgs
- A safe wrapper around NIXL optional arguments
- Registration
Handle - Xfer
Desc List - A safe wrapper around a NIXL transfer descriptor list
- Xfer
Request - A handle to a transfer request
Enums
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Nixl
Compatible - Trait for storage types that can be registered with NIXL.
- Nixl
Memory - Combined trait for memory that can be registered with NIXL.
- Nixl
Register Ext - Extension trait providing ergonomic
.register()method for NIXL registration. - Registered
View - View trait for accessing registration information without unwrapping.
- Serialize
- A data structure that can be serialized into any data format supported by Serde.
Functions
- is_stub
- register_
with_ nixl - Register storage with a NIXL agent.