pub struct NixlRegistered<S: NixlCompatible> { /* private fields */ }Expand description
Wrapper for storage that has been registered with NIXL.
This wrapper ensures proper drop order: the registration handle is dropped before the storage, ensuring deregistration happens before the memory is freed.
Implementations
Sourceimpl<S: MemoryDescriptor + NixlCompatible> NixlRegistered<S>
impl<S: MemoryDescriptor + NixlCompatible> NixlRegistered<S>
Sourcepub fn storage_mut(&mut self) -> &mut S
pub fn storage_mut(&mut self) -> &mut S
Get a mutable reference to the underlying storage.
Sourcepub fn is_registered(&self) -> bool
pub fn is_registered(&self) -> bool
Check if the registration handle is still valid.
Sourcepub fn into_storage(self) -> S
pub fn into_storage(self) -> S
Consume this wrapper and return the underlying storage.
This will deregister the storage from NIXL.