pub struct DiskStorage { /* private fields */ }Expand description
Disk-backed storage using memory-mapped files with O_DIRECT support.
Implementations
Sourceimpl DiskStorage
impl DiskStorage
Sourcepub fn new(size: usize) -> Result<Self>
pub fn new(size: usize) -> Result<Self>
Creates a new disk storage of the given size in the default cache directory.
Sourcepub fn new_at(path: impl AsRef<Path>, len: usize) -> Result<Self>
pub fn new_at(path: impl AsRef<Path>, len: usize) -> Result<Self>
Creates a new disk storage at the specified path with the given size.
Sourcepub fn unlink(&mut self) -> Result<()>
pub fn unlink(&mut self) -> Result<()>
Unlinks the backing file from the filesystem. This means that when this process terminates, the file will be automatically deleted by the OS. Unfortunately, GDS requires that files we try to register must be linked. To get around this, we unlink the file only after we’ve registered it with NIXL.