DiskStorage

Struct DiskStorage 

pub struct DiskStorage { /* private fields */ }

Implementations

Source

impl DiskStorage

pub fn new(size: usize) -> Result<Self>

pub fn new_at(path: impl AsRef<Path>, len: usize) -> Result<Self>

pub fn fd(&self) -> u64

pub fn path(&self) -> &Path

Unlink our temp file. This means that when this process terminates, the file will be automatically deleted by the OS. Unfortunately, GDS requires that files we try to register must be linked. To get around this, we unlink the file only after we’ve registered it with NIXL.

pub fn unlinked(&self) -> bool