PinnedStorage

Struct PinnedStorage 

pub struct PinnedStorage { /* private fields */ }
CUDA pinned host memory allocated via cudaHostAlloc.

Implementations

Source

impl PinnedStorage

pub fn new(len: usize) -> Result<Self>

Allocate new pinned memory of the given size.

Arguments
  • len - Size in bytes to allocate
  • device_id - CUDA device to associate with the allocation
pub unsafe fn as_ptr(&self) -> *const u8

Get a pointer to the underlying memory.

Safety

The caller must ensure the pointer is not used after this storage is dropped.

pub unsafe fn as_mut_ptr(&mut self) -> *mut u8

Get a mutable pointer to the underlying memory.

Safety

The caller must ensure the pointer is not used after this storage is dropped and that there are no other references to this memory.