pub struct PinnedStorage { /* private fields */ }Expand description
CUDA pinned host memory allocated via cudaHostAlloc.
Implementations
Sourceimpl PinnedStorage
impl PinnedStorage
Sourcepub fn new(len: usize) -> Result<Self>
pub fn new(len: usize) -> Result<Self>
Allocate new pinned memory of the given size.
Arguments
len- Size in bytes to allocatedevice_id- CUDA device to associate with the allocation
Sourcepub unsafe fn as_ptr(&self) -> *const u8
pub unsafe fn as_ptr(&self) -> *const u8
Get a pointer to the underlying memory.
Safety
The caller must ensure the pointer is not used after this storage is dropped.
Sourcepub unsafe fn as_mut_ptr(&mut self) -> *mut u8
pub unsafe fn as_mut_ptr(&mut self) -> *mut u8
Get a mutable pointer to the underlying memory.
Safety
The caller must ensure the pointer is not used after this storage is dropped and that there are no other references to this memory.